@@ -5,7 +5,3 @@ Signatures for entire Python programs.
 Extract the structure, the frame, the skeleton of your project,
 to generate API documentation or find breaking changes in your API.
 """
-
-from typing import List
-
-__all__: List[str] = []  # noqa: WPS410 (the only __variable__ we use)
